@@ -154,7 +154,7 @@ pub fn scan() -> Command {
             arg!(-r --"recursive" [MAX_DEPTH])
                 .help("Scan directories recursively")
                 .long_help(help::SCAN_RECURSIVE_LONG_HELP)
-                .default_missing_value("100")
+                .default_missing_value("1000")
                 .require_equals(true)
                 .value_parser(value_parser!(usize))
         )
@@ -237,7 +237,7 @@ impl From<&ArgMatches> for OutputOptions {
     }
 }
 
-pub fn exec_scan(args: &ArgMatches) -> anyhow::Result<()> {
+pub fn exec_scan(args: &ArgMatches, config: &Config) -> anyhow::Result<()> {
     let mut rules_path = args
         .get_many::<(Option<String>, PathBuf)>("[NAMESPACE:]RULES_PATH")
         .unwrap();
@@ -315,7 +315,7 @@ pub fn exec_scan(args: &ArgMatches) -> anyhow::Result<()> {
         // With `take()` we pass the external variables to `compile_rules`,
         // while leaving a `None` in `external_vars`. This way external
         // variables are not set again in the scanner.
-        compile_rules(rules_path, external_vars.take(), args)?
+        compile_rules(rules_path, external_vars.take(), args, config)?
     };
 
     let rules_ref = &rules;
@@ -479,13 +479,11 @@ pub fn exec_scan(args: &ArgMatches) -> anyhow::Result<()> {
             let root_cause = err.root_cause().to_string();
             let msg = if error != root_cause {
                 format!(
-                    "{} {}: {}",
+                    "{}{error}: {root_cause}",
                     "error: ".paint(Red).bold(),
-                    error,
-                    root_cause,
                 )
             } else {
-                format!("{}: {}", "error: ".paint(Red).bold(), error)
+                format!("{}{error}", "error: ".paint(Red).bold())
             };
 
             let _ = output.send(Message::Error(msg));
@@ -642,7 +640,9 @@ impl Component for ScanState {
     }
 }
 
+use crate::config::Config;
 use output_handler::*;
+
 mod output_handler {
     use super::*;
     use std::collections::HashMap;
