@@ -272,7 +272,7 @@ fn emit_expr(
 ) {
     match ir.get(expr) {
         Expr::Const(type_value) => match type_value {
-            TypeValue::Integer { value: Const(value) } => {
+            TypeValue::Integer { value: Const(value), .. } => {
                 instr.i64_const(*value);
             }
             TypeValue::Float { value: Const(value) } => {
@@ -359,7 +359,7 @@ fn emit_expr(
                             // root structure, we know that the stack already
                             // contains the object.
                             if let Some((_, true)) = ctx.lookup_list.first() {
-                                if func.method_of().is_some() {
+                                if func.is_method() {
                                     emit_lookup_object(ctx, instr);
                                 }
                             }
@@ -646,7 +646,7 @@ fn emit_expr(
                 emit_expr(ctx, ir, *expr, instr);
             }
 
-            if func_call.signature().result_may_be_undef {
+            if func_call.signature().result_may_be_undef() {
                 emit_call_and_handle_undef(
                     ctx,
                     instr,
