@@ -86,7 +86,7 @@ fn to_int(ctx: &ScanContext, string: RuntimeString) -> Option<i64> {
 }
 
 #[module_main]
-fn main(data: &[u8], _meta: Option<&[u8]>) -> TestProto2 {
+fn main(data: &[u8], _meta: Option<&[u8]>) -> Result<TestProto2, ModuleError> {
     let mut test = TestProto2::new();
 
     test.set_int32_zero(0);
@@ -178,5 +178,5 @@ fn main(data: &[u8], _meta: Option<&[u8]>) -> TestProto2 {
 
     test.set_timestamp(1748591440);
 
-    test
+    Ok(test)
 }
