@@ -50,8 +50,8 @@ static SUBDOMAIN: LazyLock<i64> = LazyLock::new(|| {
 });
 
 #[module_main]
-fn main(_data: &[u8], _meta: Option<&[u8]>) -> LiveHuntData {
-    LiveHuntData::new()
+fn main(_data: &[u8], _meta: Option<&[u8]>) -> Result<LiveHuntData, ModuleError> {
+    Ok(LiveHuntData::new())
 }
 
 #[module_export(method_of = "vt.net.EnrichedIP")]
